% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      scdist2
% from  2022-04-01 


% setup the problem
problem = setup_problem;

% generate a grid on the domain
[x1,x2] = meshgrid(linspace(0,1,41),linspace(0,1,41));

% plot the desired state
figure(1); clf; hold on
val = ud(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired state u_d');
view(3);

% plot the state constraint bound
figure(2); clf; hold on
val = ub(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('state constraint bound u_b');
view(3);

% plot the force term
figure(3); clf; hold on
val = f(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('force term f');
view(3);

% plot the optimal state
figure(4); clf; hold on
val = supplementary_u(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('optimal state u');
view(3);

% plot the optimal control
figure(5); clf; hold on
val = supplementary_q(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('optimal control q');
view(3);

% plot the optimal adjoint state
figure(6); clf; hold on
val = supplementary_z(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('optimal adjoint state z');
view(3);

